@@ -917,7 +917,6 @@ mod tests {
             Member {
                 deaf: false,
                 guild_id,
-                hoisted_role: None,
                 joined_at: None,
                 mute: false,
                 nick: None,
@@ -937,6 +936,7 @@ mod tests {
                 Role {
                     color: 0,
                     hoist: false,
+                    icon: None,
                     id: RoleId::new(1).expect("non zero"),
                     managed: false,
                     mentionable: false,
@@ -944,10 +944,12 @@ mod tests {
                     permissions: Permissions::empty(),
                     position: 0,
                     tags: None,
+                    unicode_emoji: None,
                 },
                 Role {
                     color: 0,
                     hoist: false,
+                    icon: None,
                     id: RoleId::new(2).expect("non zero"),
                     managed: false,
                     mentionable: false,
@@ -955,6 +957,7 @@ mod tests {
                     permissions: Permissions::empty(),
                     position: 1,
                     tags: None,
+                    unicode_emoji: None,
                 },
             ],
         );
