@@ -136,7 +136,7 @@ mod tests {
     use static_assertions::assert_fields;
     use twilight_model::{
         guild::{Member, PartialMember},
-        id::{GuildId, RoleId, UserId},
+        id::{GuildId, UserId},
         user::User,
     };
 
@@ -191,7 +191,6 @@ mod tests {
         let member = Member {
             deaf: false,
             guild_id: GuildId::new(3).expect("non zero"),
-            hoisted_role: Some(RoleId::new(4).expect("non zero")),
             joined_at: None,
             mute: true,
             nick: Some("member nick".to_owned()),
