@@ -9,16 +9,38 @@ use twilight_model::{
 /// [`Presence`]: twilight_model::gateway::presence::Presence
 #[derive(Clone, Debug, Eq, PartialEq, Serialize)]
 pub struct CachedPresence {
+    pub(crate) activities: Vec<Activity>,
+    pub(crate) client_status: ClientStatus,
+    pub(crate) guild_id: GuildId,
+    pub(crate) status: Status,
+    pub(crate) user_id: UserId,
+}
+
+impl CachedPresence {
     /// Current activities.
-    pub activities: Vec<Activity>,
+    pub fn activities(&self) -> &[Activity] {
+        &self.activities
+    }
+
     /// Platform-dependent status.
-    pub client_status: ClientStatus,
+    pub const fn client_status(&self) -> &ClientStatus {
+        &self.client_status
+    }
+
     /// ID of the guild.
-    pub guild_id: GuildId,
+    pub const fn guild_id(&self) -> GuildId {
+        self.guild_id
+    }
+
     /// Status of the user.
-    pub status: Status,
+    pub const fn status(&self) -> Status {
+        self.status
+    }
+
     /// ID of the user.
-    pub user_id: UserId,
+    pub const fn user_id(&self) -> UserId {
+        self.user_id
+    }
 }
 
 impl PartialEq<Presence> for CachedPresence {
